@@ -1,5 +1,5 @@
 package CGI::Builder::CgiAppAPI ;
-$VERSION = 1.22 ;
+$VERSION = 1.24 ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
@@ -160,8 +160,10 @@ $VERSION = 1.22 ;
              . qq('PH_' in all the run methods that use it)
              ; $h
              }
-        || do{ my $h = $$phm{'AUTOLOAD'} || $s->can(do{PH.'AUTOLOAD'})
-             ; $h && ++ $al && $h
+        || do{ unless ($s->page_content_check)
+                { my $h = $$phm{'AUTOLOAD'} || $s->can(do{PH.'AUTOLOAD'})
+                ; $h && ++ $al && $h
+                }
              }
       ; my $pc
       ; if ( $page_handler )
@@ -466,7 +468,7 @@ __END__
 
 CGI::Builder::CgiAppAPI - Use CGI::Application API with CGI::Builder
 
-=head1 VERSION 1.22
+=head1 VERSION 1.24
 
 The latest versions changes are reported in the F<Changes> file in this distribution. To have the complete list of all the extensions of the CBF, see L<CGI::Builder/"Extensions List">
 
@@ -495,8 +497,6 @@ From the directory where this file is located, type:
     make test
     make install
 
-B<Note>: The installation of this module runs an automatic version check connection which will warn you in case a newer version is available: please don't use old versions, because I can give you full support only for current versions. Besides, since CPAN does not provide any download statistic to the authors, this check allows me also to keep my own installation counter. Version checking is transparent to regular users, while CPAN testers should skip it by running the Makefile.PL with NO_VERSION_CHECK=1.
-
 =back
 
 =head1 SYNOPSIS
@@ -550,7 +550,7 @@ A simple and useful navigation system between the various CBF extensions is avai
 
 =item *
 
-More practical topics are probably discussed in the mailing list at this URL: L<http://lists.sourceforge.net/lists/listinfo/cgi-builder-users>
+More examples and more practical topics are available in the mailing list at this URL: L<http://lists.sourceforge.net/lists/listinfo/cgi-builder-users>
 
 =back
 
